#
# spec file for package nitroshare
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define _version 0.3
Name:           nitroshare
Version:        0.3.4
Release:        bp156.3.6
Summary:        Network file transfer application
License:        MIT
Group:          Productivity/Networking/File-Sharing
URL:            https://nitroshare.net/
Source:         https://launchpad.net/%{name}/%{_version}/%{version}/+download/%{name}-%{version}.tar.gz
Source1:        https://launchpad.net/%{name}/%{_version}/%{version}/+download/%{name}-%{version}.tar.gz.asc
Source2:        %{name}.keyring
# PATCH-FIX-UPSTREAM nitroshare-fix-caja.patch sor.alexei@meowr.ru -- Use a correct Caja GI API version.
Patch0:         %{name}-fix-caja.patch
# PATCH-FIX-OPENSUSE nitroshare-fix-qt-5.11-build.patch -- Fix Qt 5.11+ compatibility.
Patch1:         %{name}-fix-qt-5.11-build.patch
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  gobject-introspection-devel
BuildRequires:  hicolor-icon-theme
BuildRequires:  libqt5-linguist-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Gui) >= 5.1
BuildRequires:  pkgconfig(Qt5Network) >= 5.1
BuildRequires:  pkgconfig(Qt5Svg) >= 5.1
BuildRequires:  pkgconfig(Qt5Widgets) >= 5.1

%description
A network file transfer application.
Features:
 * Automatic discovery of devices on the local network.
 * Simple and intuitive user interface.
 * Transfer entire directories.

%package -n caja-extension-%{name}
Summary:        NitroShare integration for Caja
Group:          Productivity/File utilities
Requires:       %{name} = %{version}
Requires:       caja
Supplements:    packageand(caja:%{name})

%description -n caja-extension-%{name}
A network file transfer application.
This package integrates NitroShare into Caja.

%package -n nautilus-extension-%{name}
Summary:        NitroShare integration for Nautilus
Group:          Productivity/File utilities
Requires:       %{name} = %{version}
Requires:       nautilus
Supplements:    packageand(nautilus:%{name})

%description -n nautilus-extension-%{name}
A network file transfer application.
This package integrates NitroShare into Nautilus.

%package -n nemo-extension-%{name}
Summary:        NitroShare integration for Nemo
Group:          Productivity/File utilities
Requires:       %{name} = %{version}
Requires:       nemo
Supplements:    packageand(nemo:%{name})

%description -n nemo-extension-%{name}
A network file transfer application.
This package integrates NitroShare into Nemo.

%package kde
Summary:        NitroShare integration into KDE
Group:          Productivity/File utilities
Requires:       %{name} = %{version}

%description kde
A network file transfer application.
This package integrates NitroShare into the KDE service menu.

%prep
%setup -q
%patch0 -p1
%patch1 -p1

%build
%cmake
make %{?_smp_mflags} V=1

%install
%cmake_install
%suse_update_desktop_file -r %{name} Network FileTransfer

%if 0%{?suse_version} < 1500
%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun
%endif

%files
%if 0%{?suse_version} >= 1500
%license LICENSE.txt
%else
%doc LICENSE.txt
%endif
%doc README.md
%{_bindir}/%{name}
%{_bindir}/%{name}-send
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/*
%{_mandir}/man?/%{name}.?%{?ext_man}

%files -n caja-extension-%{name}
%{_datadir}/caja-python/

%files -n nautilus-extension-%{name}
%{_datadir}/nautilus-python/

%files -n nemo-extension-%{name}
%{_datadir}/nemo-python/

%files kde
%dir %{_datadir}/kservices5/
%{_datadir}/kservices5/nitroshare_addtoservicemenu.desktop

%changelog
* Tue Jun 12 2018 sor.alexei@meowr.ru
- Add nitroshare-fix-qt-5.11-build.patch: Fix Qt 5.11+
  compatibility.
- Some clean-up.
* Mon Feb 12 2018 jengelh@inai.de
- Ensure neutrality of description.
* Mon Jan 29 2018 pascal.bleser@opensuse.org
- Update to version 0.3.4:
  * mDNS discovery for compatibility with the Android app
  * quarantine mode when receiving transfers
  * Arabic, German, Italian, and Polish translations added
  * add button to open transfer directory to transfer window
* Sat Oct  8 2016 sor.alexei@meowr.ru
- Remove the appindicator dependency: causes problems.
* Mon Jul 18 2016 jengelh@inai.de
- Trim filelist.
* Thu Jul 14 2016 sor.alexei@meowr.ru
- Update to version 0.3.3:
  * Extensions for Caja & Nemo.
  * Fix a bug that broke progress and status display.
  * Fix a number of DPI issues.
  * Add French, Korean, & Spanish translations.
- Add nitroshare-fix-caja.patch: use a correct Caja GI API version.
* Tue Jul 12 2016 sor.alexei@meowr.ru
- Update to version 0.3.2:
  * Local HTTP API.
  * Nautilus extension.
  * Support for TLS encryption.
  * Option for starting at login.
  * Runtime detection of Unity.
* Wed Feb  3 2016 sor.alexei@meowr.ru
- Update to 0.3.1:
  * Switch the build system to CMake.
  * Remove colour from the logo.
  * Better platform integration.
  * Options for:
    + preventing NitroShare from receiving files;
    + choosing whether files are overwritten when received;
  * Add warning for GNOME users that an extension is required.
- Use the signed tarball.
* Thu Mar 26 2015 sor.alexei@meowr.ru
- Initial package.
